    ''''
    	Declaration
    		Statement
    		Sign
    		Notification
    		Notice
    		Memo
    "'''

    ''''
    * has external links
    * requires saving packets in the browser.
    "'''

    ''''
    Once open, the party that agrees to this must take full responsibility for every play that happens on the opened trinket.
    The party agrees to allow this trinket to save bits to browser local storage.
    "'''